%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Jyvaskylan yliopiston Fysiikan laitoksen LuK-tutkielma (jyflluk.cls)
% Dokumenttiluokka
% Versio 1.4 (13/03/2017)
% 
% Alkuperäinen tekijä:
% Jussi Maunuksela (jussi.o.maunuksela at jyu.fi)
%
% Lisenssi:
% CC BY-NC-SA 3.0 (http://creativecommons.org/licenses/by-nc-sa/3.0/)
%
% Muutokset:
%
% 2015-11-10 (1.3) - Lisätty: icomma.cls
%                  - Muutettu riviväli: 1.0 -> 1.5
% 2016-01-08 (1.4) - Poistettu kaksoiskirjaimet / disabled ligatures
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\ProvidesClass{jyflluk}[2017/03/13 versio 1.4 JYFL kandidaatintutkielman dokumenttiluokka]
\NeedsTeXFormat{LaTeX2e}

% ================================================================
% DOKUMENTTILUOKAN MÄÄRITELMÄT:
%
% Ladataan article -dokumenttiluokka seuraavilla lisämääreillä:
%
%   12pt    - Perusfontin pistekoko
%   a4paper - Paperikoko
%   

%% Load base
\LoadClass[12pt,a4paper,twoside]{article}

%% Load additional packages and commands

% Input encoding: Unicode UTF-8 encoding support (default)
\RequirePackage[utf8]{inputenc}

% Font choices: Latin Modern (similar to CM with more characters)
\RequirePackage[T1]{fontenc} % encoding containing umlaut letters
\RequirePackage{lmodern} % Computer Modern-like fonts with T1 support
\RequirePackage[final]{microtype}
\DisableLigatures[f]{encoding = *, family = *} % no combining f with an adjacent letter
\RequirePackage{icomma} % proper spacing in decimal numbers

% Customising captions: 
\RequirePackage[margin=10pt,labelfont=bf,labelsep=period]{caption}[2013/02/03]

% Hyphenation rules: Finnish, English
\RequirePackage[english,finnish]{babel} % Active language: Finnish

% Language definitions: References, Figure
\addto\captionsfinnish{%
  \renewcommand{\refname}{Lähteet} % Lähdeluettelon otsikko
  \renewcommand{\figurename}{Kuvio} % Kuvatekstin otsikko
}

% Set paper size, margins and headheight
\RequirePackage[a4paper,left=25mm,right=25mm,top=35mm,bottom=35mm,bindingoffset=10mm]{geometry}
\setlength{\headheight}{15pt}

% More space between lines
\linespread{1.3} % For one-and-a-half spacing you have to use 1.3. 

% Header and footer settings
\RequirePackage{fancyhdr}
\fancypagestyle{firstpage}{%
  \fancyhf{}% clear all six fields
  \renewcommand{\headrulewidth}{0pt} %
  \renewcommand{\footrulewidth}{0pt} %
}
\fancypagestyle{followingpage}{%
  \fancyhf{}% clear all six fields
  \fancyhead[LE,RO]{\thepage}%
  \renewcommand{\headrulewidth}{0pt}%
  \renewcommand{\footrulewidth}{0pt}%
}
\pagestyle{followingpage}
\AtBeginDocument{\thispagestyle{firstpage}}

% Section titles
\RequirePackage[noindentafter,nobottomtitles,toctitles]{titlesec}
\newcommand{\sectionbreak}{%
	\cleardoublepage%
	\vspace*{24pt}}

% Add references to contents
\RequirePackage[nottoc]{tocbibind}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% GRAPHICX --- Grafiikan lisääminen dokumenttiin. Oletuksen dokumentin tulostaminen pdf-muotoon
%
\RequirePackage{graphicx}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% HYPERREF --- Hyperlinkkien ladonta tekstin sekaan. 
%
\RequirePackage[final]{hyperref}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% LASTPAGE --- Dokumentin viimeiseen sivuun viittaaminen. 
%
\RequirePackage{lastpage}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% BOOKTABS --- Taulukoiden piirtäminen käyttäen viivoja, joiden ympärille jää sopivasti tilaa.
%
\RequirePackage{booktabs}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% DATETIME --- Päiväyksen muotoilu
%
\RequirePackage{datetime}
\renewcommand{\dateseparator}{.}
\setdefaultdate{\dmyyyydate}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% URL --- URL-osoitteiden ladonta
%
\RequirePackage{url}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% JYFLTITLE --- Kansilehden ladonta
%
\RequirePackage{jyflTitle}






